@@ -6,12 +6,12 @@ class OkStep(StandardStep):
     Name = "ok_step.py"
 
     def __init__(self, service, scenario: Scenario):
-        self.service = service
-        self.scenario = scenario
-        self.service.step_definitions[self.Name] = self
+        super().__init__(service, scenario)
 
     def _pre_processor(self): ...
 
     def call_back(self, **kwargs): assert kwargs.get("ok").procCode() == 200
 
-    def _execute(self): self.service.post_method_json(data=dict(username="xx", pwd="yyy"))
+    def _execute(self):
+        super()._execute()
+        self.service.post_method_json(data=dict(username="xx", pwd="yyy"))
